==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/hr.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenti",
"Can't create document" => "Dokument nije moguće kreirati",
"You don't have permission to rename this document" => "Nije vam dopušteno preimenovati ovaj dokument",
"Directory saved successfully." => "Direktorij uspješno spremljen.",
"An error occurred while changing directory." => "Pogreška pri mijenjaju direktorija.",
"Saved" => "Spremljeno",
"Format filter server is down or misconfigured" => "Poslužitelj za filtriranje formata je pao ili je pogrešno konfiguriran",
"Conversion failed. Check log for details." => "Pretvorba nije uspjela. Za detalje provjerite zapisnik.",
"Saving..." => "Spremanje...",
"Failed to load documents." => "Učitavanje dokumenata nije uspjelo",
"No documents were found. Upload or create a document to get started!" => "Nikakvi dokumenti nisu nađeni. Za početak, učitajte ili kreirajte neki dokument!",
"No connection to server. Trying to reconnect." => "Nema kontakta s poslužiteljem.Ponovno pokušajte uspostaviti vezu",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Napuštanje ove stranice u načinu rada za uređivanje može rezultirati nespremljenim podacima.Umjesto toga, preporučuje se pritisnuti gumb 'Zatvorite'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Učitavanje ovog dokumenta nije uspjelo. MOlimo provjerite može li ga se otvoritis nekim vanjskim odt uređivačem. To također može značiti da je njegovo dijeljenjezaustavljeno ili da je izbrisan.",
"Save" => "Spremite",
"Loading documents..." => "Učitavanje dokumenata...",
"'.' is an invalid file name." => "'.' je neispravan naziv datoteke",
"File name cannot be empty." => "Naziv datoteke ne može biti prazan",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Neispravan naziv, '\\', '/', '<', '>', ':', '\"', '|', '?'  i '*' nisu dopušteni.",
"Align Left" => "Poravnanje slijeva",
"Alignment" => "Poravnanje",
"Align Right" => "Poravnanje sdesna",
"Annotate" => "Stavite primjedbu",
"Background" => "Pozadina",
"Bold" => "Podebljano",
"Bottom" => "Dno",
"Cancel" => "Odustanite",
"Center" => "Centar",
"Clone" => "Klonirajte",
"Clone this Style" => "KLonirajte ovaj stil",
"Close" => "Zatvorite",
"Color" => "Boja",
"Create" => "Kreirajte",
"Decrease Indent" => "Smanjite uvlaku",
"Default Style" => "Zadani stil",
"Delete" => "Izbrišite",
"Family" => "Obitelj",
"Font" => "Font",
"Font Effects" => "Efekti fonta",
"Format" => "Format",
"Increase Indent" => "Povećajte uvlaku",
"Insert Image" => "Umetnite sliku",
"Invite Members" => "Pozovite članove",
"Italic" => "Kurziv",
"Justified" => "Obostrano",
"Justify" => "Poravnajte obostrano",
"Left" => "Lijevo",
"Loading" => "Učitavanje",
"Members" => "Članovi",
"New Name:" => "Novi naziv:",
"OK" => "OK",
"Open" => "Otvorite",
"Options" => "Mogućnosti",
"Paragraph..." => "Odlomak",
"Paragraph Styles" => "Stil odlomka",
"Redo" => "Ponovite poništeno",
"Right" => "Desno",
"Size" => "Veličina",
"Spacing" => "Razmak",
"Strikethrough" => "Precrtano",
"Style" => "Stil",
"Text" => "Tekst",
"Top" => "Vrh",
"Underline" => "Podcrtano",
"Undo" => "Poništite",
"Unknown Author" => " Autor nepoznat",
"Edit" => "Uređivanje",
"Share" => "Dijelite zajedničke resurse",
"guest" => "Gost",
"MS Word support (requires openOffice/libreOffice)" => "MS Word podrška (obavezan openOffice/libreOffice)",
"Local" => "Lokalno",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice je instaliran na ovom poslužitelju. Put do binarnogomogućen je putem preview_libreoffice_path u config.php",
"External" => "Vanjsko",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice je instaliran na vanjskom poslužitelju koji pokreće poslužiteljza filtriranje formata",
"Disabled" => "Onemogućeno",
"scheme://domain.tld[:port]" => "shema: //domain.tld[:port]",
"Server URL" => "URL poslužitelja",
"Apply and test" => "Primijenite i testirajte",
"New document" => "Novi dokument",
"Upload (max. %s)" => "Učitavanje (max. %s)",
"Upload" => "Učitavanje",
"Save new documents to" => "Novi dokument spremite na",
"Wrong password. Please retry." => "Pogrešna lozinka. Molimo pokušajte ponovno",
"Password" => "Lozinka",
"Guest %s" => "Gost %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Ova veza je istekla ili nikad nije postojala. Za detalje, molimo kontaktirajte osobu kojaju je s vama podijelila.",
"Advanced feature-set" => "Napredan skup značajki",
"(Unstable)" => "(Nestabilno)"
);
$PLURAL_FORMS = "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;";

==> owncloud-app-documents-1%3A9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/hr.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenti",
"Can't create document" => "Dokument nije moguće kreirati",
"You don't have permission to rename this document" => "Nije vam dopušteno preimenovati ovaj dokument",
"Directory saved successfully." => "Direktorij uspješno spremljen.",
"An error occurred while changing directory." => "Pogreška pri mijenjaju direktorija.",
"Saved" => "Spremljeno",
"Format filter server is down or misconfigured" => "Poslužitelj za filtriranje formata je pao ili je pogrešno konfiguriran",
"Conversion failed. Check log for details." => "Pretvorba nije uspjela. Za detalje provjerite zapisnik.",
"Saving..." => "Spremanje...",
"Failed to load documents." => "Učitavanje dokumenata nije uspjelo",
"No documents were found. Upload or create a document to get started!" => "Nikakvi dokumenti nisu nađeni. Za početak, učitajte ili kreirajte neki dokument!",
"No connection to server. Trying to reconnect." => "Nema kontakta s poslužiteljem.Ponovno pokušajte uspostaviti vezu",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Napuštanje ove stranice u načinu rada za uređivanje može rezultirati nespremljenim podacima.Umjesto toga, preporučuje se pritisnuti gumb 'Zatvorite'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Učitavanje ovog dokumenta nije uspjelo. MOlimo provjerite može li ga se otvoritis nekim vanjskim odt uređivačem. To također može značiti da je njegovo dijeljenjezaustavljeno ili da je izbrisan.",
"Save" => "Spremite",
"Loading documents..." => "Učitavanje dokumenata...",
"'.' is an invalid file name." => "'.' je neispravan naziv datoteke",
"File name cannot be empty." => "Naziv datoteke ne može biti prazan",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Neispravan naziv, '\\', '/', '<', '>', ':', '\"', '|', '?'  i '*' nisu dopušteni.",
"Align Left" => "Poravnanje slijeva",
"Alignment" => "Poravnanje",
"Align Right" => "Poravnanje sdesna",
"Annotate" => "Stavite primjedbu",
"Background" => "Pozadina",
"Bold" => "Podebljano",
"Bottom" => "Dno",
"Cancel" => "Odustanite",
"Center" => "Centar",
"Clone" => "Klonirajte",
"Clone this Style" => "KLonirajte ovaj stil",
"Close" => "Zatvorite",
"Color" => "Boja",
"Create" => "Kreirajte",
"Decrease Indent" => "Smanjite uvlaku",
"Default Style" => "Zadani stil",
"Delete" => "Izbrišite",
"Family" => "Obitelj",
"Font" => "Font",
"Font Effects" => "Efekti fonta",
"Format" => "Format",
"Increase Indent" => "Povećajte uvlaku",
"Insert Image" => "Umetnite sliku",
"Invite Members" => "Pozovite članove",
"Italic" => "Kurziv",
"Justified" => "Obostrano",
"Justify" => "Poravnajte obostrano",
"Left" => "Lijevo",
"Loading" => "Učitavanje",
"Members" => "Članovi",
"New Name:" => "Novi naziv:",
"OK" => "OK",
"Open" => "Otvorite",
"Options" => "Mogućnosti",
"Paragraph..." => "Odlomak",
"Paragraph Styles" => "Stil odlomka",
"Redo" => "Ponovite poništeno",
"Right" => "Desno",
"Size" => "Veličina",
"Spacing" => "Razmak",
"Strikethrough" => "Precrtano",
"Style" => "Stil",
"Text" => "Tekst",
"Top" => "Vrh",
"Underline" => "Podcrtano",
"Undo" => "Poništite",
"Unknown Author" => " Autor nepoznat",
"Shared" => "Resurs podijeljen",
"Error" => "Pogreška",
"Error while sharing" => "Pogreška pri dijeljenju",
"Error while unsharing" => "Pogreška pri prestanku dijeljenja",
"Error while changing permissions" => "POgreška pri mijenjanju dozvola",
"Shared with you and the group {group} by {owner}" => "Dijeljeno s vama i grupom {group} vlasnika {owner}",
"Shared with you by {owner}" => "S vama podijelio {owner}",
"Share with users or groups …" => "Podijeli sa korisnicima ili grupama ...",
"Share with users, groups or remote users …" => "Podijeli sa korisnicima, grupama ili udaljenim korisnicima ...",
"Share" => "Dijelite zajedničke resurse",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Podijelite sa korisnicima drugoga ownClouda koristeći format korisnickoime@primjer.com/owncloud",
"Share link" => "Podijelite vezu",
"The public link will expire no later than {days} days after it is created" => " Javna veza ističe najkasnije {days} dana nakon što je kreirana",
"Link" => "Poveznica",
"Password protect" => "Zaštititi lozinkom",
"Password" => "Lozinka",
"Choose a password for the public link" => "Odaberite lozinku za javnu vezu",
"Allow editing" => "Omogući uređivanje",
"Email link to person" => "Pošaljite osobi vezu e-poštom",
"Send" => "Pošaljite",
"Set expiration date" => "Odredite datum isteka",
"Expiration" => "Istjeće",
"Expiration date" => "Datum isteka",
"An error occured. Please try again" => "Dogodila se pogreška. Molimo Vas, pokušajte ponovno. ",
"Adding user..." => "Dodavanje korisnika...",
"group" => "Grupa",
"remote" => "na daljinu",
"Resharing is not allowed" => "Ponovno dijeljenje nije dopušteno",
"Shared in {item} with {user}" => "Podijeljeno u {item} sa {user}",
"Unshare" => "Prestanite dijeliti",
"notify by email" => "Obavijestite e-poštom",
"can share" => "Dijeljenje moguće",
"can edit" => "Uređivanje moguće",
"access control" => "Kontrola pristupa",
"create" => "Kreirajte",
"change" => "promijeni",
"delete" => "Izbrišite",
"Password protected" => "Lozinka zaštićena",
"Error unsetting expiration date" => "Pogrešno uklanjanje postavke datuma isteka",
"Error setting expiration date" => "Pogrešno učitavanje postavke datuma isteka",
"Sending ..." => "Slanje...",
"Email sent" => "E-pošta je poslana",
"Warning" => "Upozorenje",
"Edit" => "Uređivanje",
"guest" => "Gost",
"MS Word support (requires openOffice/libreOffice)" => "MS Word podrška (obavezan openOffice/libreOffice)",
"Local" => "Lokalno",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice je instaliran na ovom poslužitelju. Put do binarnogomogućen je putem preview_libreoffice_path u config.php",
"External" => "Vanjsko",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice je instaliran na vanjskom poslužitelju koji pokreće poslužiteljza filtriranje formata",
"Disabled" => "Onemogućeno",
"No MS Word support" => "Nema podrške za MS Word",
"scheme://domain.tld[:port]" => "shema: //domain.tld[:port]",
"Server URL" => "URL poslužitelja",
"Apply and test" => "Primijenite i testirajte",
"New document" => "Novi dokument",
"Upload (max. %s)" => "Učitavanje (max. %s)",
"Upload" => "Učitavanje",
"Save new documents to" => "Novi dokument spremite na",
"Wrong password. Please retry." => "Pogrešna lozinka. Molimo pokušajte ponovno",
"Guest %s" => "Gost %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Ova veza je istekla ili nikad nije postojala. Za detalje, molimo kontaktirajte osobu kojaju je s vama podijelila.",
"Advanced feature-set" => "Napredan skup značajki",
"(Unstable)" => "(Nestabilno)"
);
$PLURAL_FORMS = "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;";
